@@ -41,7 +41,8 @@ ClosePol <- function(mtrx) {
 #' @name st_cast
 #' @export
 #' @examples 
-#' example(st_read)
+#' # example(st_read)
+#' nc = st_read(system.file("shape/nc.shp", package="sf"))
 #' mpl <- nc$geometry[[4]]
 #' #st_cast(x) ## error 'argument "to" is missing, with no default'
 #' cast_all <- function(xg) {
@@ -217,12 +218,21 @@ st_cast.MULTISURFACE <- function(x, to, ...) {
 #' @name st_cast
 #' @export
 st_cast.COMPOUNDCURVE <- function(x, to, ...) {
-	if (! missing(to))
-		stop("to should be missing")
+	if (! missing(to) && to != "LINESTRING")
+		stop("to should be missing or LINESTRING")
 	CPL_compoundcurve_to_linear(structure(list(x), crs = NA_crs_, precision = 0.0, 
 		class = c("sfc_COMPOUNDCURVE", "sfc")))[[1]]
 }
 
+#' @name st_cast
+#' @export
+st_cast.MULTICURVE <- function(x, to, ...) {
+	if (! missing(to) && to != "MULTILINESTRING")
+		stop("to should be missing or MULTILINESTRING")
+	st_multilinestring(lapply(x, st_cast, to = "LINESTRING"))
+}
+
+
 #' @name st_cast
 #' @export
 st_cast.CURVE <- function(x, to, ...) { # nocov start
