@@ -96,8 +96,6 @@ st_buffer.sfc = function(x, dist, nQuadSegs = 30,
 #		if (!missing(nQuadSegs) || !missing(endCapStyle) || !missing(joinStyle) ||
 #				!missing(mitreLimit) || !missing(singleSide))
 #			warning("all bufer style parameters are ignored; set st_use_s2(FALSE) first to use them")
-		if (! requireNamespace("s2", quietly = TRUE))
-			stop("package s2 required, please install it first")
 		if (inherits(dist, "units")) {
 			if (!inherits(try(units(dist) <- as_units("rad"), silent = TRUE), "try-error"))
 				return(st_as_sfc(s2::s2_buffer_cells(x, dist, radius = 1, ...),
@@ -211,8 +209,6 @@ st_simplify.sfc = function(x, preserveTopology = FALSE, dTolerance = 0.0) {
 	if (ll && sf_use_s2()) {
 		if (!missing(preserveTopology))
 			warning("argument preserveTopology is ignored")
-		if (! requireNamespace("s2", quietly = TRUE))
-			stop("package s2 required, please install it first")
 		st_as_sfc(s2::s2_simplify(x, dTolerance), crs = st_crs(x))
 	} else {
 		stopifnot(mode(preserveTopology) == 'logical')
@@ -243,7 +239,7 @@ st_triangulate.sfg = function(x, dTolerance = 0.0, bOnlyEdges = FALSE)
 
 #' @export
 st_triangulate.sfc = function(x, dTolerance = 0.0, bOnlyEdges = FALSE) {
-	if (CPL_geos_version() >= "3.4.0") {
+	if (compareVersion(CPL_geos_version(), "3.4.0") > -1) { # >= ; see https://github.com/r-spatial/sf/issues/1653
 		if (isTRUE(st_is_longlat(x)))
 			warning("st_triangulate does not correctly triangulate longitude/latitude data")
 		st_sfc(CPL_geos_op("triangulate", x, numeric(0), integer(0),
@@ -266,7 +262,7 @@ st_triangulate.sf = function(x, dTolerance = 0.0, bOnlyEdges = FALSE) {
 #' \code{nQuadSegs} controls the number of points per quadrant to approximate the circle.
 #' \code{st_inscribed_circle} requires GEOS version 3.9 or above
 #' @examples
-#' if (sf_extSoftVersion()["GEOS"] >= "3.9.0") {
+#' if (compareVersion(sf_extSoftVersion()[["GEOS"]], "3.9.0") > -1) {
 #'   nc_t = st_transform(nc, 'EPSG:2264')
 #'   x = st_inscribed_circle(st_geometry(nc_t))
 #'   plot(st_geometry(nc_t), asp = 1, col = grey(.9))
@@ -282,7 +278,7 @@ st_inscribed_circle.sfg = function(x, dTolerance, ...) {
 
 #' @export
 st_inscribed_circle.sfc = function(x, dTolerance = sqrt(st_area(st_set_crs(x, NA_crs_)))/1000, ..., nQuadSegs = 30) {
-	if (CPL_geos_version() >= "3.9.0") {
+	if (compareVersion(CPL_geos_version(), "3.9.0") > -1) { # >=
 		if (isTRUE(st_is_longlat(x)))
 			warning("st_inscribed_circle does not work correctly for longitude/latitude data")
 		nQ = rep(nQuadSegs, length.out = length(x))
@@ -313,7 +309,7 @@ st_inscribed_circle.sf = function(x, dTolerance, ...) {
 #' set.seed(1)
 #' x = st_multipoint(matrix(runif(10),,2))
 #' box = st_polygon(list(rbind(c(0,0),c(1,0),c(1,1),c(0,1),c(0,0))))
-#' if (sf_extSoftVersion()["GEOS"] >= "3.5.0") {
+#' if (compareVersion(sf_extSoftVersion()[["GEOS"]], "3.5.0") > -1) {
 #'  v = st_sfc(st_voronoi(x, st_sfc(box)))
 #'  plot(v, col = 0, border = 1, axes = TRUE)
 #'  plot(box, add = TRUE, col = 0, border = 1) # a larger box is returned, as documented
@@ -343,7 +339,7 @@ st_voronoi.sfg = function(x, envelope = st_polygon(), dTolerance = 0.0, bOnlyEdg
 
 #' @export
 st_voronoi.sfc = function(x, envelope = st_polygon(), dTolerance = 0.0, bOnlyEdges = FALSE) {
-	if (sf_extSoftVersion()["GEOS"] >= "3.5.0") {
+	if (compareVersion(CPL_geos_version(), "3.5.0") > -1) {
 		if (isTRUE(st_is_longlat(x)))
 			warning("st_voronoi does not correctly triangulate longitude/latitude data")
 		st_sfc(CPL_geos_voronoi(x, st_sfc(envelope), dTolerance = dTolerance,
@@ -441,11 +437,9 @@ st_centroid.sfc = function(x, ..., of_largest_polygon = FALSE) {
 			x[multi] = largest_ring(x[multi])
 	}
 	longlat = isTRUE(st_is_longlat(x))
-	if (longlat && sf_use_s2()) {
-		if (! requireNamespace("s2", quietly = TRUE))
-			stop("package s2 required, please install it first")
+	if (longlat && sf_use_s2())
 		st_as_sfc(s2::s2_centroid(x), crs = st_crs(x))
-	} else { 
+	else { 
 		if (longlat)
 			warning("st_centroid does not give correct centroids for longitude/latitude data")
 		st_sfc(CPL_geos_op("centroid", x, numeric(0), integer(0), numeric(0), logical(0)))
@@ -495,7 +489,7 @@ st_point_on_surface.sf = function(x) {
 #' @export
 #' @details \code{st_reverse} reverses the nodes in a line
 #' @examples
-#' if (sf_extSoftVersion()["GEOS"] >= "3.7.0") {
+#' if (compareVersion(sf_extSoftVersion()[["GEOS"]], "3.7.0") > -1) {
 #'   st_reverse(st_linestring(rbind(c(1,1), c(2,2), c(3,3))))
 #' }
 #nocov start
@@ -633,14 +627,12 @@ geos_op2_geom = function(op, x, y, s2_model = "semi-open", ...) {
 	y = st_geometry(y)
 	longlat = isTRUE(st_is_longlat(x))
 	if (longlat && sf_use_s2()) {
-		if (! requireNamespace("s2", quietly = TRUE))
-			stop("package s2 required, please install it first")
 		fn = switch(op, intersection = s2::s2_intersection,
 				difference = s2::s2_difference,
 				sym_difference = s2::s2_sym_difference,
 				union = s2::s2_union, stop("invalid operator"))
 		# to be optimized -- this doesn't index on y:
-		lst = structure(unlist(lapply(x, fn, y, s2::s2_options(model = s2_model, ...)),
+		lst = structure(unlist(lapply(y, function(yy) fn(x, yy, s2::s2_options(model = s2_model, ...))),
 			recursive = FALSE), class = "s2_geography")
 		e = s2::s2_is_empty(lst)
 		idx = cbind(rep(seq_along(x), length(y)), rep(seq_along(y), each = length(x)))
@@ -736,7 +728,7 @@ st_intersection.sf = function(x, y, ...) {
 		x[[ sf_column ]] = structure(geom, idx = NULL)
 		st_sf(x)
 	} else
-		geos_op2_df(x, y, geos_op2_geom("intersection", x, y))
+		geos_op2_df(x, y, geos_op2_geom("intersection", x, y, ...))
 }
 
 #' @name geos_binary_ops
@@ -778,7 +770,7 @@ st_difference.sf = function(x, y, ...) {
 		x[[ sf_column ]] = structure(geom, idx = NULL)
 		st_sf(x)
 	} else
-		geos_op2_df(x, y, geos_op2_geom("difference", x, y))
+		geos_op2_df(x, y, geos_op2_geom("difference", x, y, ...))
 }
 
 #' @name geos_binary_ops
@@ -883,7 +875,7 @@ st_union.sfc = function(x, y, ..., by_feature = FALSE, is_coverage = FALSE) {
 		else {
 			if (ll)
 				message_longlat("st_union")
-			geos_op2_geom("union", x, y)
+			geos_op2_geom("union", x, y, ...)
 		}
 	}
 }
@@ -897,7 +889,7 @@ st_union.sf = function(x, y, ..., by_feature = FALSE, is_coverage = FALSE) {
 		else
 			geom
 	} else
-		geos_op2_df(x, y, geos_op2_geom("union", x, y))
+		geos_op2_df(x, y, geos_op2_geom("union", x, y, ...))
 }
 
 #' Sample points on a linear geometry
