@@ -185,8 +185,8 @@ Rcpp::List CPL_crs_parameters(Rcpp::List crs) {
 	if (srs == NULL)
 		Rcpp::stop("crs not found"); // #nocov
 
-	Rcpp::List out(13);
-	Rcpp::CharacterVector names(13);
+	Rcpp::List out(14);
+	Rcpp::CharacterVector names(14);
 	out(0) = Rcpp::NumericVector::create(srs->GetSemiMajor());
 	names(0) = "SemiMajor";
 
@@ -268,6 +268,18 @@ Rcpp::List CPL_crs_parameters(Rcpp::List crs) {
 #endif
 	names(12) = "ProjJson";
 
+	// WKT1_ESRI
+#if GDAL_VERSION_MAJOR >= 3
+	const char *options[3] = { "MULTILINE=YES", "FORMAT=WKT1_ESRI", NULL };
+	if (srs->exportToWkt(&cp, options) != OGRERR_NONE)
+		out(13) = Rcpp::CharacterVector::create(NA_STRING);
+	else
+		out(13) = Rcpp::CharacterVector::create(cp);
+#else
+	out(13) = "";
+#endif
+	names(13) = "WKT1_ESRI";
+
 	set_error_handler();
 
 	delete srs;
